@@ -1,6 +1,6 @@
 package UV;
 
-our $VERSION = '1.900';
+our $VERSION = '1.901';
 our $XS_VERSION = $VERSION;
 
 use strict;
@@ -581,7 +581,7 @@ Returns a new L<UV::Timer> object.
 
 =head2 tty
 
-    my $tty = UV::TTY(fd => 0);
+    my $tty = UV::tty(fd => 0);
 
 Returns a new L<UV::TTY> object.
 
